# {{project_name}}

Project auto-generated by create-mountaineer-app. Check the mountaineer documentation for more information on getting started.

## Getting Started

{% if use_poetry %}
Install the dependencies with poetry:

```bash
poetry install
```

Then start your server:

```bash
poetry run runserver
```
{% else %}
Create a virtual environment to house the project dependencies. If you've already created an environment through create-mountaineer-app, you can skip this step:

```bash
python -m venv venv
source venv/bin/activate
pip install -e .
```

Then start your server:

```bash
source venv/bin/activate
runserver
```
{% endif %}
